@@ -8,6 +8,7 @@ __all__ = [
     "draw_pred",
     "draw_bbox",
     "draw_mask",
+    "draw_keypoints",
 ]
 
 from icevision.imports import *
@@ -22,13 +23,17 @@ def draw_sample(
     display_label: bool = True,
     display_bbox: bool = True,
     display_mask: bool = True,
+    display_keypoints: bool = True,
 ):
     img = sample["img"].copy()
     if denormalize_fn is not None:
         img = denormalize_fn(img)
 
-    for label, bbox, mask in itertools.zip_longest(
-        sample.get("labels", []), sample.get("bboxes", []), sample.get("masks", [])
+    for label, bbox, mask, keypoints in itertools.zip_longest(
+        sample.get("labels", []),
+        sample.get("bboxes", []),
+        sample.get("masks", []),
+        sample.get("keypoints", []),
     ):
         color = (np.random.random(3) * 0.6 + 0.4) * 255
 
@@ -45,6 +50,8 @@ def draw_sample(
                 class_map=class_map,
                 color=color,
             )
+        if display_keypoints and keypoints is not None:
+            img = draw_keypoints(img=img, kps=keypoints, color=color)
 
     return img
 
@@ -107,6 +114,7 @@ def draw_record(
     display_label: bool = True,
     display_bbox: bool = True,
     display_mask: bool = True,
+    display_keypoints: bool = True,
 ):
     sample = record.load()
     return draw_sample(
@@ -115,6 +123,7 @@ def draw_record(
         display_label=display_label,
         display_bbox=display_bbox,
         display_mask=display_mask,
+        display_keypoints=display_keypoints,
     )
 
 
@@ -216,3 +225,26 @@ def draw_mask(
     img[border_idxs] = color
 
     return img
+
+
+def draw_keypoints(
+    img: np.ndarray,
+    kps: KeyPoints,
+    color: Tuple[int, int, int],
+):
+    x, y, v, sks = kps.x, kps.y, kps.visible, kps.human_conns
+
+    # for sk in sks:
+    #     if np.all(v[sk] > 0):
+    #         cv2.line(
+    #             img,
+    #             (x[sk][0], y[sk][0]),
+    #             (x[sk][1], y[sk][1]),
+    #             color=color,
+    #             thickness=3,
+    #         )
+
+    for x_c, y_c in zip(x[v > 0], y[v > 0]):
+        cv2.circle(img, (x_c, y_c), radius=5, color=color, thickness=-1)
+
+    return img
